@@ -1,5 +1,5 @@
 /* internal.h --- Internal header with hidden library handle structures.
- * Copyright (C) 2002, 2003, 2004, 2005, 2006, 2008  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009  Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -82,7 +82,9 @@ struct Gsasl_session
   Gsasl_mechanism *mech;
   void *mech_data;
   void *application_hook;
-  /* Properties. */
+
+  /* Properties.  If you add anything here, remember to change change
+     gsasl_finish() in xfinish.c and map() in property.c.  */
   char *anonymous_token;
   char *authid;
   char *authzid;
@@ -94,10 +96,21 @@ struct Gsasl_session
   char *hostname;
   char *gssapi_display_name;
   char *realm;
+  char *digest_md5_hashed_password;
+  char *qops;
+  char *qop;
+
 #ifndef GSASL_NO_OBSOLETE
   /* Obsolete stuff. */
   void *application_data;
 #endif
 };
 
+#ifndef GSASL_NO_OBSOLETE
+const char *
+_gsasl_obsolete_property_map (Gsasl_session * sctx, Gsasl_property prop);
+int _gsasl_obsolete_callback (Gsasl * ctx, Gsasl_session * sctx,
+			      Gsasl_property prop);
+#endif
+
 #endif /* INTERNAL_H */
