@@ -81,6 +81,14 @@ doit (void)
       return;
     }
 
+  if (!gsasl_client_support_p (ctx, "CRAM-MD5")
+      || !gsasl_server_support_p (ctx, "CRAM-MD5"))
+    {
+      gsasl_done (ctx);
+      fail("No support for CRAM-MD5.\n");
+      exit(77);
+    }
+
   gsasl_callback_set (ctx, callback);
 
   for (i = 0; i < 5; i++)
